@@ -88,6 +88,7 @@
 
 #else  /* !NATIVE_WIN32 */
 
+#ifndef __EMX__
 /* Unix */
 
 #define G_DIR_SEPARATOR '/'
@@ -95,6 +96,16 @@
 #define G_SEARCHPATH_SEPARATOR ':'
 #define G_SEARCHPATH_SEPARATOR_S ":"
 
+#else
+/* EMX/OS2 */
+
+#define G_DIR_SEPARATOR '/'
+#define G_DIR_SEPARATOR_S "/"
+#define G_SEARCHPATH_SEPARATOR ';'
+#define G_SEARCHPATH_SEPARATOR_S ";"
+
+#endif
+
 #endif /* !NATIVE_WIN32 */
 
 #ifdef __cplusplus
@@ -262,11 +273,11 @@ extern "C" {
  * macros, so we can refer to them as strings unconditionally.
  */
 #ifdef	__GNUC__
-#define	G_GNUC_FUNCTION		(__FUNCTION__)
-#define	G_GNUC_PRETTY_FUNCTION	(__PRETTY_FUNCTION__)
+#define	G_GNUC_FUNCTION		__FUNCTION__
+#define	G_GNUC_PRETTY_FUNCTION	__PRETTY_FUNCTION__
 #else	/* !__GNUC__ */
-#define	G_GNUC_FUNCTION		("")
-#define	G_GNUC_PRETTY_FUNCTION	("")
+#define	G_GNUC_FUNCTION		""
+#define	G_GNUC_PRETTY_FUNCTION	""
 #endif	/* !__GNUC__ */
 
 /* we try to provide a usefull equivalent for ATEXIT if it is
@@ -668,6 +679,11 @@ GUTILS_C_VAR const guint glib_micro_version;
 GUTILS_C_VAR const guint glib_interface_age;
 GUTILS_C_VAR const guint glib_binary_age;
 
+#define GLIB_CHECK_VERSION(major,minor,micro)    \
+    (GLIB_MAJOR_VERSION > (major) || \
+     (GLIB_MAJOR_VERSION == (major) && GLIB_MINOR_VERSION > (minor)) || \
+     (GLIB_MAJOR_VERSION == (major) && GLIB_MINOR_VERSION == (minor) && \
+      GLIB_MICRO_VERSION >= (micro)))
 
 /* Forward declarations of glib types.
  */
@@ -697,6 +713,7 @@ typedef struct _GTuples		GTuples;
 typedef union  _GTokenValue	GTokenValue;
 typedef struct _GIOChannel	GIOChannel;
 
+/* Tree traverse flags */
 typedef enum
 {
   G_TRAVERSE_LEAFS	= 1 << 0,
@@ -705,6 +722,7 @@ typedef enum
   G_TRAVERSE_MASK	= 0x03
 } GTraverseFlags;
 
+/* Tree traverse orders */
 typedef enum
 {
   G_IN_ORDER,
@@ -2395,12 +2413,14 @@ struct _GSourceFuncs
 {
   gboolean (*prepare)  (gpointer  source_data, 
 			GTimeVal *current_time,
-			gint     *timeout);
+			gint     *timeout,
+			gpointer  user_data);
   gboolean (*check)    (gpointer  source_data,
-			GTimeVal *current_time);
-  gboolean (*dispatch) (gpointer  source_data, 
 			GTimeVal *current_time,
 			gpointer  user_data);
+  gboolean (*dispatch) (gpointer  source_data, 
+			GTimeVal *dispatch_time,
+			gpointer  user_data);
   GDestroyNotify destroy;
 };
 
@@ -2427,7 +2447,7 @@ gboolean g_source_remove_by_source_data      (gpointer       source_data);
 gboolean g_source_remove_by_funcs_user_data  (GSourceFuncs  *funcs,
 					      gpointer       user_data);
 
-void g_get_current_time		    (GTimeVal	   *result);
+void g_get_current_time		        (GTimeVal	*result);
 
 /* Running the main loop */
 GMainLoop*	g_main_new		(gboolean	 is_running);
